#
# spec file for package maven-native
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global namedversion 1.0-M1
Name:           maven-native
Version:        1.0~M1
Release:        2.2
Summary:        Maven plugin to compile C and C++ source
License:        Apache-2.0 AND MIT
Group:          Development/Libraries/Java
URL:            https://www.mojohaus.org/plugins.html
# Source code available @ https://github.com/mojohaus/maven-native
Source0:        https://repo1.maven.org/maven2/org/codehaus/mojo/natives/%{name}/%{namedversion}/%{name}-%{namedversion}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mojo-parent
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.bcel:bcel)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-aether-provider)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-compat)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.mojo:mojo-parent:pom:)
BuildRequires:  mvn(org.codehaus.plexus:plexus-archiver)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-annotations)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildRequires:  mvn(org.codehaus.plexus:plexus-container-default)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus-xml)
BuildArch:      noarch

%description
Maven Native - compile C and C++ source under Maven
with compilers such as GCC, MSVC, GCJ etc ...

%package components
Summary:        Maven Native Components
Group:          Development/Libraries/Java

%description components
%{summary}.

%package -n native-maven-plugin
Summary:        Native Maven Plugin
Group:          Development/Libraries/Java

%description -n native-maven-plugin
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-%{namedversion}

%pom_remove_plugin -r :sortpom-maven-plugin

%{mvn_package} ":%{name}" %{name}
%{mvn_package} ":%{name}-api" %{name}
%{mvn_package} ":%{name}-components" components
%{mvn_package} ":%{name}-bcc" components
%{mvn_package} ":%{name}-generic-c" components
%{mvn_package} ":%{name}-javah" components
%{mvn_package} ":%{name}-manager" components
%{mvn_package} ":%{name}-msvc" components
%{mvn_package} ":%{name}-mingw" components
%{mvn_package} ":native-maven-plugin" native-maven-plugin
# Empty, manifest-only jar
%{mvn_package} ":%{name}-test" __noinstall

%build

%{mvn_build} -f -s -- -Dmojo.java.target=8 -Dmaven.test.failure.ignore=true -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles-%{name}
%dir %{_javadir}/%{name}
%license LICENSE.txt

%files components -f .mfiles-components
%license LICENSE.txt

%files -n native-maven-plugin -f .mfiles-native-maven-plugin
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Wed Jun 12 2024 Fridrich Strba <fstrba@suse.com>
- Fix build with mojo-parent >= 3.1.0
* Tue Apr 30 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to maven-native 1.0-M1
  * Changes
    + Require Maven 3.5.4+
    + Require Java 8
    + add Microsoft Visual Studio C++ 2019 support - issue #39
    + Fix Windows build issue #29 "master@maven-native does not
    build on Windows 10 with VS2017: 8 failed tests".
    Windows build is breaking because
    org.codehaus.plexus.util.cli.Commandline#getCommandline()
    has operating system dependent code referencing
    org.codehaus.plexus.util.Os.FAMILY_WINDOWS.
    + local output timestamp for Reproducible Builds
- Removed pregenerated plexus components.xml, since they are
  generated by plexus-component-metadata plugin
- Removed patch:
  * 0001-Require-Java-8.patch
    + integrated in this version
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon May 23 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 0001-Require-Java-8.patch
    + Backport upstream changes that fix infinite loops on some
    architectures
* Fri Mar 25 2022 Fridrich Strba <fstrba@suse.com>
- Put back the plexus components.xml files from alpha-8, since
  they are not correctly genrated from the annotations
* Wed Jul 28 2021 Fridrich Strba <fstrba@suse.com>
- Clean-up the spec file a bit
* Thu Oct  8 2020 Fridrich Strba <fstrba@suse.com>
- Upgrade to maven-native 1.0-alpha-11
  * includes many fixes in how libraries are created
  * includes new parameters in configuration that are increasingly
    used out there
* Mon Jun  3 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
- Add missing Group: for javadoc subpackage.
* Fri May  3 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-native 1.0-alpha-8
